/*
  Copyright 1996-2001
  Simon Whiteside

* $Id: XMLExecutable.java,v 1.12 2001/05/09 10:30:18 sdw Exp $
*/
package simkin;
import java.io.*;
import com.sun.xml.tree.*;
import org.xml.sax.*;
import org.w3c.dom.*;
import java.util.*;

/**
 * This class is a base class for objects which store their data and methods in an XML document
 *<p>Each instance is associated with an XML document which is loaded on construction. 
 */
public class XMLExecutable extends XMLElementObject {
    /**
     * This is the XML document loaded for this object
     */
    XmlDocument m_Doc;
    /**
     * Default Constructor.
     */
    public XMLExecutable() {
    }
    /**
     * Constructor taking an input stream containing an XML document
     * @throws SAXException where there was a syntax error in the XML stream
     * @throws IOException where there was an error loading the stream
     */
    public XMLExecutable(InputStream in) throws SAXException, IOException {
	load(in);
    }
    /**
     * This method causes the XML to be reloaded
     * @param in - stream containing the XML
     */
    public void load(InputStream in) throws SAXException, IOException{
	m_Doc=XmlDocument.createXmlDocument(new InputSource(in),false);
	setElement(m_Doc.getDocumentElement());
    }
    /**
     * Call this method to save the state of the object back to a stream
     * @exception IOException if there was an error writing to the stream
     */
    public void save(OutputStream out) throws IOException{
	m_Doc.write(out);
    }
}


